import sys, os
import numpy as np
import re
if sys.stdin.isatty():
    print("No input provided. Please pipe data into this script.", file=sys.stderr)
    sys.exit(1)

if not "XY" in os.environ:
    print("XY not set", file=sys.stderr)

data = []
shortest_line_length = -1
for line in sys.stdin:
    parts = re.split(r'[^0-9.eE+\-]+', line)
    line_data = [float(x.strip().strip(",") or "nan") for x in parts if len(x) > 0]
    data.append(line_data)
    if shortest_line_length == -1:
        shortest_line_length = len(line_data)
    if shortest_line_length > len(line_data):
        shortest_line_length = len(line_data)
        print(f"Lines do not contain the same number of values. Truncating to {shortest_line_length} values", file=sys.stderr)

data = np.array([x[:shortest_line_length] for x in data])


import sys
import ast
import numpy as np


def main():
    if sys.stdin.isatty():
        print("No input provided. Please pipe data into this script.", file=sys.stderr)
        sys.exit(1)

    if len(sys.argv) < 2:
        print("No lambda provided. Please provide a lambda as an argument. Example labmda x: len(x.split(",")) > 1, just provide \"len(x.split(",")) > 1\"", file=sys.stderr)
        sys.exit(1)

    tree = ast.parse(f"lambda x: {sys.argv[1]}", mode='eval')
    f = eval(compile(tree, filename='<ast>', mode='eval'))
    for x in filter(f, sys.stdin):
        print(x[:-1])



import numpy as np
from .flat import data

print(f"Count: {np.count_nonzero(np.isnan(data) == False)}")
print(f"Minimum: {np.nanmin(data)}")
print(f"Maximum: {np.nanmax(data)}")
print(f"Mean: {np.nanmean(data)}")
print(f"Std: {np.nanstd(data)}")
print(f"Q05: {np.nanquantile(data, 0.05)}")
print(f"Q25: {np.nanquantile(data, 0.25)}")
print(f"Q50/median: {np.nanquantile(data, 0.50)}")
print(f"Q75: {np.nanquantile(data, 0.75)}")
print(f"Q95: {np.nanquantile(data, 0.95)}")

# for the entrypoint
def main():
    pass


import sys, os
import json

if not "DEBUG" in os.environ:
    if sys.stdin.isatty():
        print("No input provided. Please pipe data into this script.", file=sys.stderr)
        sys.exit(1)
    input = sys.stdin
else:
    from tqdm import tqdm
    folder = "/home/jonas/rl-tools/src/foundation_policy/dynamics_parameters"
    input = []
    for file in tqdm(os.listdir(folder)):
        if file.endswith(".json"):
            with open(os.path.join(folder, file), 'r') as f:
                input.append(f.read())
    input = input[:10]

data = []
header = []

def get_value_from_dict(path, obj):
    path_parts = path.split('.')
    if len(path_parts) == 1:
        return obj[path_parts[0]] if path_parts[0] in obj else None
    else:
        return get_value_from_dict('.'.join(path_parts[1:]), obj[path_parts[0]]) if path_parts[0] in obj else None
def flatten(obj):
    if not isinstance(obj, dict) and not isinstance(obj, list):
        raise ValueError("Input must be a dictionary or a list")
    if isinstance(obj, dict):
        items = obj.items()
    elif isinstance(obj, list):
        items = enumerate(obj)
    for key, value in items:
        if isinstance(value, dict) or isinstance(value, list):
            for inner_key, inner_value in flatten(value):
                yield ".".join([str(key), str(inner_key)]), inner_value
        else:
            yield str(key), value


def main():
    keys = set()
    data = []
    for line in input:
        json_data = line.strip()
        json_obj = json.loads(json_data)
        items = dict(flatten(json_obj))
        data.append(items)
        keys.update(items.keys())


    keys = sorted(keys)

    print(",".join(keys))
    for row in data:
        output_row = []
        for key in keys:
            value = row.get(key, None)
            if isinstance(value, str):
                value = value.replace(",", " ")
            elif value is None:
                value = ""
            output_row.append(str(value))
        print(",".join(output_row))



if __name__ == "__main__":
    main()


import sys
import numpy as np
from .flat import data

if len(sys.argv) != 2:
    print("Usage: p2s.q <quantile in %> e.g. \"p2s.q 25\" for 25%")
    exit(1)
quantile = float(sys.argv[1])
print(f"{np.nanquantile(data, quantile/100)}")


# for the entrypoint
def main():
    pass


import sys
import os
import csv
import numpy as np
import matplotlib.pyplot as plt
import argparse


def main():
    parser = argparse.ArgumentParser(description="Plot correlation matrix from CSV data")
    parser.add_argument("--variates", type=str, help="Comma-separated list of variate names to include in the correlation matrix. The semantics are: All to variates correlation (N_VARIATES x N_ALL)", default=None)
    parser.add_argument("--variate-startswith", type=str, help="filter variates that start with this substring", default=None)
    args = parser.parse_args()

    if "DEBUG" in os.environ:
        input = open(os.environ["DEBUG"], 'r')
    else:
        input = sys.stdin
    reader = csv.reader(input)
    header = next(reader)
    rows = [row for row in reader]

    data = []
    for row in rows:
        output_row = []
        for x in row:
            if x == "" or x.lower() == "nan" or x.lower() == "null" or x.lower() == "undefined" or x.lower() == "none":
                x = None
            else:
                try:
                    x = float(x)
                except ValueError:
                    if x == "True":
                        x = 1
                    elif x == "False":
                        x = 0
                    else:
                        x = None
            output_row.append(x)
        data.append(output_row)

    data = np.array(data)

    corr = np.corrcoef(data, rowvar=False)

    if args.variates:
        variates = [x.strip() for x in args.variates.split(",")]
        variate_indices = [header.index(variate) for variate in variates if variate in header]
        if not variate_indices:
            print("No valid variates found in the header. Exiting.")
            return
        corr = corr[np.ix_(variate_indices, range(len(header)))]
    
    EPS = 1e-5
    colindices = [i for i in range(corr.shape[1]) if (not np.any(np.isnan(corr[:, i]))) and (not np.any(np.abs(corr[:, i]) < EPS)) and (not args.variate_startswith or any([header[i].startswith(x) for x in args.variate_startswith.split(",")]))]
    if len(colindices) < corr.shape[1]:
        corr = corr[:, colindices]
        header = [header[i] for i in colindices]


    fig, ax = plt.subplots()
    cax = ax.matshow(corr, cmap='coolwarm', vmin=-1, vmax=1)
    fig.colorbar(cax)

    ax.set_xticks(range(len(header)))
    if parser.parse_args().variates:
        yticklabels = variates
    else:
        yticklabels = header
    ax.set_yticks(range(len(yticklabels)))
    ax.set_xticklabels(header, rotation=90)
    ax.set_yticklabels(yticklabels)

    plt.tight_layout()
    plt.show()



if __name__ == "__main__":
    main()


import sys
import numpy as np
from .flat import data

if len(sys.argv) != 3:
    print("Usage: p2s.iqm <quantile in %>  <quantile in %> e.g. \"p2s.q 25 75\" for 25% - 75%")
    exit(1)
lower_quantile = float(sys.argv[1])
upper_quantile = float(sys.argv[2])


lower_threshold = np.nanquantile(data, lower_quantile / 100)
upper_threshold = np.nanquantile(data, upper_quantile / 100)

filtered_data = data[(data >= lower_threshold) & (data <= upper_threshold)]
print(f"{np.nanmean(filtered_data)}")

# for the entrypoint
def main():
    pass


import sys
import numpy as np
if sys.stdin.isatty():
    print("No input provided. Please pipe data into this script.", file=sys.stderr)
    sys.exit(1)
data = np.array([float(x.strip().strip(",") or "nan") for x in sys.stdin])